Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc
diff --git a/chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc b/chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc
index bbc94864a8fce33eba362cb1a0ea269130dc6c3a..7ecbbcad57d1b64f267a222cd733c6143f30d551 100644
--- a/chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc
+++ b/chrome/browser/browsing_data/browsing_data_file_system_helper_unittest.cc
@@ -15,18 +15,18 @@
#include "content/public/browser/storage_partition.h"
#include "content/public/test/test_browser_thread.h"
#include "content/public/test/test_browser_thread_bundle.h"
-#include "webkit/browser/fileapi/file_system_context.h"
-#include "webkit/browser/fileapi/file_system_url.h"
-#include "webkit/common/fileapi/file_system_types.h"
+#include "storage/browser/fileapi/file_system_context.h"
+#include "storage/browser/fileapi/file_system_url.h"
+#include "storage/common/fileapi/file_system_types.h"
using content::BrowserContext;
using content::BrowserThread;
namespace {
-// Shorter names for fileapi::* constants.
-const fileapi::FileSystemType kTemporary = fileapi::kFileSystemTypeTemporary;
-const fileapi::FileSystemType kPersistent = fileapi::kFileSystemTypePersistent;
+// Shorter names for storage::* constants.
+const storage::FileSystemType kTemporary = storage::kFileSystemTypeTemporary;
+const storage::FileSystemType kPersistent = storage::kFileSystemTypePersistent;
// We'll use these three distinct origins for testing, both as strings and as
// GURLs in appropriate contexts.
@@ -92,7 +92,7 @@ class BrowsingDataFileSystemHelperTest : public testing::Test {
}
// Callback that should be executed in response to
- // fileapi::FileSystemContext::OpenFileSystem.
+ // storage::FileSystemContext::OpenFileSystem.
void OpenFileSystemCallback(const GURL& root,
const std::string& name,
base::File::Error error) {
@@ -101,8 +101,8 @@ class BrowsingDataFileSystemHelperTest : public testing::Test {
}
bool OpenFileSystem(const GURL& origin,
- fileapi::FileSystemType type,
- fileapi::OpenFileSystemMode open_mode) {
+ storage::FileSystemType type,
+ storage::OpenFileSystemMode open_mode) {
BrowserContext::GetDefaultStoragePartition(profile_.get())->
GetFileSystemContext()->OpenFileSystem(
origin, type, open_mode,
@@ -113,15 +113,15 @@ class BrowsingDataFileSystemHelperTest : public testing::Test {
return open_file_system_result_ == base::File::FILE_OK;
}
// Calls fileapi::FileSystemContext::OpenFileSystem with
// OPEN_FILE_SYSTEM_FAIL_IF_NONEXISTENT flag
// to verify the existence of a file system for a specified type and origin,
// blocks until a response is available, then returns the result
// synchronously to it's caller.
bool FileSystemContainsOriginAndType(const GURL& origin,
- fileapi::FileSystemType type) {
- return OpenFileSystem(origin, type,
- fileapi::OPEN_FILE_SYSTEM_FAIL_IF_NONEXISTENT);
+ storage::FileSystemType type) {
+ return OpenFileSystem(
+ origin, type, storage::OPEN_FILE_SYSTEM_FAIL_IF_NONEXISTENT);
}
// Callback that should be executed in response to StartFetching(), and stores
@@ -172,9 +172,9 @@ class BrowsingDataFileSystemHelperTest : public testing::Test {
// Calls OpenFileSystem with OPEN_FILE_SYSTEM_CREATE_IF_NONEXISTENT
// to create a filesystem of a given type for a specified origin.
void CreateDirectoryForOriginAndType(const GURL& origin,
- fileapi::FileSystemType type) {
- OpenFileSystem(origin, type,
- fileapi::OPEN_FILE_SYSTEM_CREATE_IF_NONEXISTENT);
+ storage::FileSystemType type) {
+ OpenFileSystem(
+ origin, type, storage::OPEN_FILE_SYSTEM_CREATE_IF_NONEXISTENT);
EXPECT_EQ(base::File::FILE_OK, open_file_system_result_);
}
@@ -219,7 +219,7 @@ TEST_F(BrowsingDataFileSystemHelperTest, FetchData) {
EXPECT_FALSE(ContainsKey(info->usage_map, kPersistent));
EXPECT_TRUE(ContainsKey(info->usage_map, kTemporary));
EXPECT_EQ(kEmptyFileSystemSize,
- info->usage_map[fileapi::kFileSystemTypeTemporary]);
+ info->usage_map[storage::kFileSystemTypeTemporary]);
} else if (info->origin == kOrigin2) {
EXPECT_FALSE(test_hosts_found[1]);
test_hosts_found[1] = true;
@@ -113,15 +113,15 @@ class BrowsingDataFileSystemHelperTest : public testing::Test {
return open_file_system_result_ == base::File::FILE_OK;
}
- // Calls fileapi::FileSystemContext::OpenFileSystem with
+ // Calls storage::FileSystemContext::OpenFileSystem with
// OPEN_FILE_SYSTEM_FAIL_IF_NONEXISTENT flag
// to verify the existence of a file system for a specified type and origin,
« no previous file with comments | « chrome/browser/browsing_data/browsing_data_file_system_helper.cc ('k') | chrome/browser/browsing_data/browsing_data_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698